fnss.netconfig.delays.get_delays — FNSS 0.6.1 documentation

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- FNSS 0.6.1 documentation »
- API Reference »
- Functions »

# fnss.netconfig.delays.get_delays

`get_delays`(topology)

  Returns all the delays.

  Parameters: | topology : Topology The topology whose link delays are requested
  Returns: | delays : dict Dictionary of link delays keyed by link.

  Examples

      >>> import fnss
      >>> topology = fnss.Topology()
      >>> topology.add_path([1,2,3])
      >>> fnss.set_delays_constant(topology, 10, 'ms')
      >>> delay = get_delays(topology)
      >>> delay[(1,2)]
      10

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- FNSS 0.6.1 documentation »
- API Reference »
- Functions »